package com.chelvc.framework.feign.circuitbreaker;

import com.chelvc.framework.base.context.ApplicationContextHolder;
import io.github.resilience4j.circuitbreaker.CircuitBreaker;
import io.github.resilience4j.circuitbreaker.configure.CircuitBreakerAspectExt;
import org.aspectj.lang.ProceedingJoinPoint;
import org.springframework.stereotype.Component;

/**
 * 熔断降级处理拦截器
 *
 * @author Woody
 * @date 2025/4/15
 */
@Component
public class CircuitBreakerInterceptor implements CircuitBreakerAspectExt {
    @Override
    public boolean canHandleReturnType(Class returnType) {
        return true;
    }

    @Override
    public Object handle(ProceedingJoinPoint point, CircuitBreaker circuitBreaker, String method) throws Throwable {
        boolean enabled = ApplicationContextHolder.getProperty("circuit.breaker.enabled", boolean.class, true);
        if (enabled) {
            return circuitBreaker.executeCheckedSupplier(point::proceed);
        }
        return point.proceed();
    }
}
